/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  DroppableListBox							//
//  ----------------							//
//									//
//  A list box that accepts URL drops onto it.  Used for the list of	//
//  additional WADs (PWADs).						//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>
#include <klocale.h>

#include <kurl.h>
#include <kurldrag.h>

#include <qlistbox.h>
#include <qevent.h>

#include "droppablelistbox.h"
#include "droppablelistbox.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

DroppableListBox::DroppableListBox(QWidget *parent)
	: QListBox(parent)
{
	setAcceptDrops(true);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Drag and drop events						//
//									//
//////////////////////////////////////////////////////////////////////////

void DroppableListBox::dragEnterEvent(QDragEnterEvent *event)
{
	event->accept(KURLDrag::canDecode(event));
}


void DroppableListBox::dropEvent(QDropEvent *event)
{
	KURL::List urls;

	// See if we can decode the drop as a URI.  If not, just ignore it.
	if (KURLDrag::decode(event,urls) && !urls.isEmpty())
	{
		KURL::List::iterator it;
		for (it = urls.begin(); it != urls.end(); ++it)
		{
			const KURL &url = (*it);
			if (url.isValid()) emit dropped(url);
		}
	}
}
