/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  EdgeEnemiesOptions							//
//  ------------------							//
//									//
//  Specific options in the 'Enemies' dialogue for the EDGE engine.	//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdialog.h>
#include <klocale.h>

#include <qcheckbox.h>
#include <qbuttongroup.h>

#include "edgeenemiesoptions.h"
#include "edgeenemiesoptions.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

EdgeEnemiesOptions::EdgeEnemiesOptions(QWidget *parent,EnemiesOptions::Option opt)
	: EnemiesOptions(parent,opt)
{
	buttongroup->addSpace(2*KDialog::spacingHint());

	infighting = new QCheckBox(i18n("Monster infighting"),buttongroup);
							// "Monster Infighting" option
	moreblood = new QCheckBox(i18n("Extra blood"),buttongroup);
							// "Extra blood" option
	buttongroup->adjustSize();			// probably needed again

	if (opt & EnemiesOptions::Infight) infighting->setChecked(true);
	if (opt & EnemiesOptions::MoreBlood) moreblood->setChecked(true);

	connect(nomonsters,SIGNAL(toggled(bool)),this,SLOT(slotToggledMonsters(bool)));

	slotToggledMonsters(nomonsters->isChecked());	// set initial enable state
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Action slots							//
//									//
//////////////////////////////////////////////////////////////////////////

void EdgeEnemiesOptions::slotToggledMonsters(bool state)
{
	infighting->setEnabled(!state);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Returned results							//
//									//
//////////////////////////////////////////////////////////////////////////

EnemiesOptions::Option EdgeEnemiesOptions::options() const
{
	int opt = EnemiesOptions::options();
	if (infighting->isChecked()) opt |= EnemiesOptions::Infight;
	if (moreblood->isChecked()) opt |= EnemiesOptions::MoreBlood;
	return ((EnemiesOptions::Option) opt);
}
