/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  EnemiesOptions							//
//  --------------							//
//									//
//  The generic 'Enemies' options dialogue, with common and useful	//
//  options.  Some game engines may add options to or remove		//
//  them from this dialogue.						//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdialog.h>
#include <klocale.h>

#include <qcheckbox.h>
#include <qbuttongroup.h>

#include "enemiesoptions.h"
#include "enemiesoptions.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Text strings							//
//									//
//////////////////////////////////////////////////////////////////////////

static const QString capt = i18n("Enemies Options");

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

EnemiesOptions::EnemiesOptions(QWidget *parent,EnemiesOptions::Option opt)
	: KDialogBase(parent)
{
	setCaption(capt);
	showButtonApply(false);				// uses "OK" and "cancel" only

	buttongroup = new QButtonGroup(1,Qt::Horizontal,capt,this);
	setMainWidget(buttongroup);			// main (and only) group box
							// "No Monsters" option
	nomonsters = new QCheckBox(i18n("No monsters"),buttongroup);
	connect(nomonsters,SIGNAL(toggled(bool)),this,SLOT(slotToggledMonsters(bool)));
							// "Respawning Monsters" option
	respmonsters = new QCheckBox(i18n("Respawning monsters"),buttongroup);
							// "Fast Monsters" option
	fastmonsters = new QCheckBox(i18n("Fast monsters"),buttongroup);

	buttongroup->adjustSize();

	if (opt & EnemiesOptions::None) nomonsters->setChecked(true);
	if (opt & EnemiesOptions::Respawn) respmonsters->setChecked(true);
	if (opt & EnemiesOptions::Fast) fastmonsters->setChecked(true);

	slotToggledMonsters(nomonsters->isChecked());
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Action slots							//
//									//
//////////////////////////////////////////////////////////////////////////

void EnemiesOptions::slotToggledMonsters(bool state)
{
	respmonsters->setEnabled(!state);
	fastmonsters->setEnabled(!state);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Returned results							//
//									//
//////////////////////////////////////////////////////////////////////////

EnemiesOptions::Option EnemiesOptions::options() const
{
	int opt = EnemiesOptions::Null;
	if (nomonsters->isChecked()) opt |= EnemiesOptions::None;
	if (respmonsters->isChecked()) opt |= EnemiesOptions::Respawn;
	if (fastmonsters->isChecked()) opt |= EnemiesOptions::Fast;
	return ((EnemiesOptions::Option) opt);
}
