/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  GameManager								//
//  -----------								//
//									//
//  This class maintains and searches the list of supported game	//
//  engines, and information about each of them.			//
//									//
//////////////////////////////////////////////////////////////////////////

#ifndef __GAMEMANAGER_H
#define __GAMEMANAGER_H

#include <qstring.h>
#include <qptrlist.h>

class GenericGame;
class QWidget;

class GameManager
{

public:
	static GameManager *self();

	typedef GenericGame * (*createFunction)(QWidget *);
	struct gameInfo
	{
		QString key;
		QString name;
		QString url;
		QString notes;
		QString execname;
		QString execpaths;
		QString datapaths;
		GameManager::createFunction create;
	};

	void add(const GameManager::gameInfo *info);
	GenericGame *create(const QString &key,QWidget *parent);

	const GameManager::gameInfo *findNamed(const QString &name) const;
	const GameManager::gameInfo *findInfo(const QString &key) const;
	const GameManager::gameInfo *firstInfo() const;
	const GameManager::gameInfo *nextInfo() const;

	const QString findExecFor(const GameManager::gameInfo *g) const;
	const QString findDataFor(const GameManager::gameInfo *g) const;

	static const QString wadFilterText;
	static const QString wadCaptionText;

	static const QString lmpFilterText;
	static const QString lmpCaptionText;

private:
	GameManager();
	~GameManager();

	QPtrList<GameManager::gameInfo> *games;
};

#endif							// GAMEMANAGER_H
