/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  GenericGame								//
//  -----------								//
//									//
//  This is the base class of all the implementation classes for the	//
//  game engines that are supported.					//
//									//
//////////////////////////////////////////////////////////////////////////


#ifndef __GENERICGAME_H
#define __GENERICGAME_H

#include <qstring.h>
#include <qstringlist.h>
#include <qwidget.h>

#include "displayoptions.h"
#include "soundoptions.h"
#include "enemiesoptions.h"

class KURLRequester;
class KActionCollection;
class KXMLGUIClient;
class KAction;
class KConfig;

class QComboBox;
class QListBox;

class PWadList;
class RemoteFiles;

class GenericGame : public QWidget
{
	Q_OBJECT

public:
	GenericGame(QWidget *parent);
	virtual ~GenericGame();
	virtual void setupActions(KXMLGUIClient *client);
	virtual void readOptions(KConfig *config);
	virtual void saveOptions(KConfig *config);
	virtual void checkPlayAllowed();
	virtual QString getPlayCommand(QStringList &cmd);
	void checkForNewSaves();
	void setWadDataDirectory(const QString &location);
	virtual const GameManager::gameInfo *gameInfo() = 0;

protected:
	virtual QStringList findSavedGames() = 0;
	virtual const QString configName() { return ("GenericGame"); }

	virtual QString getMainWad(QStringList &cmd,RemoteFiles *files,const KURL &u);
	virtual QString getPWads(QStringList &cmd,RemoteFiles *files,QListBox *list);

	virtual QString playLoadGame(QStringList &cmd,const QString &load);
	virtual QString playPlayDemo(QStringList &cmd,RemoteFiles *files,const KURL &lmp);
	virtual QString playStartLevel(QStringList &cmd,const QString &warp,int skill);
	virtual QString optionsDisplay(QStringList &cmd);
	virtual QString optionsEnemies(QStringList &cmd);
	virtual QString optionsSound(QStringList &cmd);

	virtual QString demoFormat() const;

signals:
	void readyToPlay(bool ok,bool demo);

protected slots:
	void slotDisplayOptions();
	void slotSoundOptions();
	void slotEnemiesOptions();
	void slotExtraOptions();
	void slotSelectedWad(const QString &file = QString::null);
	void slotSelectedLmp(const QString &file = QString::null);
	void slotClearDemo();
	void slotDemoInfo();
	virtual void slotOptionsChanged();

protected:
	QSize displaysize;
	DisplayOptions::Option displayoption;
	SoundOptions::Option soundoption;
	EnemiesOptions::Option enemiesoption;
	QString extraargs;

private:
	KURLRequester *mainwad;
	PWadList *pwads;
	bool wadvalid;

	KURLRequester *demolmp;
	QPushButton *demoinfo;

	QComboBox *loadgame;
	QListBox *startlevel;
	QComboBox *skill;

	KAction *advdisplay;
	KAction *advsound;
	KAction *advenemies;
	KAction *advextra;

	int loadsaved;
};

#endif							// GENERICGAME_H
