/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  Main								//
//  ----								//
//									//
//  Main program and application information.				//
//									//
//////////////////////////////////////////////////////////////////////////

#include <klocale.h>
#include <kapplication.h>
#include <dcopclient.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "mainobject.h"
#include "mainwindow.h"

//////////////////////////////////////////////////////////////////////////
//									//
//  Application information						//
//									//
//////////////////////////////////////////////////////////////////////////

static const char description[] = I18N_NOOP("Desktop front-end for Doom-like games");
static const char author[]      = I18N_NOOP("Jonathan Marten");
static const char copyright[]   = I18N_NOOP("(C) 2008 Jonathan Marten");
static const char email[]       = "jjm@keelhaul.me.uk";
static const char apphome[]     = "http://www.keelhaul.me.uk/linux/kadoom";
static const char authorhome[]  = "http://www.keelhaul.me.uk";

//////////////////////////////////////////////////////////////////////////
//									//
//  Command line options						//
//									//
//////////////////////////////////////////////////////////////////////////

static KCmdLineOptions options[] =
{
    { "n", I18N_NOOP( "Testing only, don't run the game engine" ), 0 },
    KCmdLineLastOption
};


bool optionTestingOnly = false;

//////////////////////////////////////////////////////////////////////////
//									//
//  Main								//
//									//
//////////////////////////////////////////////////////////////////////////

int main(int argc,char **argv)
{
    KAboutData about(PACKAGE,I18N_NOOP("Kadoom"),VERSION,description,
                     KAboutData::License_GPL,copyright,NULL,apphome,email);
    about.addAuthor(author,email,authorhome);
    KCmdLineArgs::init(argc,argv,&about);
    KCmdLineArgs::addCmdLineOptions(options);

    KApplication app;
    if (app.isRestored())				// starting with session management?
    {
	    RESTORE(KadoomMainWindow);
    }
    else						// not session management
    {
        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
	if (args->isSet("n")) optionTestingOnly = true;	// handle command line arguments
	args->clear();					// apparently "fixes memory leak"

	new KadoomMainObject();				// create and show main window
    }

    return (app.exec());
}
