/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  MainObject								//
//  ----------								//
//									//
//  This object persists for the lifetime of the application.  It	//
//  manages creation and deletion of the main widget, which is		//
//  specific to the selected game engine.				//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>
#include <kapplication.h>

#include <qtimer.h>

#include "mainwindow.h"

#include "mainobject.h"
#include "mainobject.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

KadoomMainObject::KadoomMainObject()
{
	mainwin = NULL;					// not created yet
	slotEngineChanged2();				// but do that now
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Game engine switching						//
//									//
//  The deletion and recreation needs to be deferred until idle,	//
//  because the object being deleted (the KadoomMainWindow) itself	//
//  emits the engineChanged() signal.  Deleting the main window		//
//  immediately	would result in a return to the deleted object,		//
//  quickly followed by a crash.					//
//									//
//////////////////////////////////////////////////////////////////////////

void KadoomMainObject::slotEngineChanged()
{
	kdDebug(0) << k_funcinfo << endl;
	QTimer::singleShot(0,this,SLOT(slotEngineChanged2()));
}


void KadoomMainObject::slotEngineChanged2()
{
	kdDebug(0) << k_funcinfo << endl;

	KApplication::kApplication()->setMainWidget(NULL);
	if (mainwin!=NULL) mainwin->hide();
	delete mainwin;

	mainwin = new KadoomMainWindow();
	connect(mainwin,SIGNAL(engineChanged()),this,SLOT(slotEngineChanged()));
	KApplication::kApplication()->setMainWidget(mainwin);
	mainwin->show();
}
