/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  MatchRequester							//
//  --------------							//
//									//
//  Dialogue for the user to select from a list of possible files.	//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>
#include <klocale.h>
#include <kdialogbase.h>

#include <qstringlist.h>
#include <qlayout.h>
#include <qlistbox.h>
#include <qcheckbox.h>
#include <qlabel.h>

#include "matchrequester.h"
#include "matchrequester.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

MatchRequester::MatchRequester(QWidget *parent,const QString &message,
			       const QStringList &list,bool optionRemember)
	: KDialogBase(parent)
{
	canRemember = optionRemember;			// can we do this?

	setCaption(i18n("Select From List"));
	showButtonApply(false);				// uses "OK" and "Cancel" only

	QWidget *w = new QWidget(this);			// main widget and layout
	QVBoxLayout *vb = new QVBoxLayout(w,KDialog::marginHint(),KDialog::spacingHint());

	QLabel *lab = new QLabel(message,w);		// message at top
	vb->addWidget(lab);

	QStringList sl = list;				// sort input list alphabetically
	sl.sort();

	listBox = new QListBox(w);			// list box in centre
	listBox->setSelectionMode(QListBox::Single);
	listBox->setVScrollBarMode(QScrollView::AlwaysOn);
	listBox->setMinimumHeight(80);
	listBox->insertStringList(sl);
	connect(listBox,SIGNAL(selectionChanged()),this,SLOT(slotChangedSelection()));
	vb->addWidget(listBox,1);
							// check box at bottom
	saveCheck = new QCheckBox(i18n("Remember this selection (until the cache is cleared)"),w);
	vb->addWidget(saveCheck);
	if (!canRemember) saveCheck->setEnabled(false);

	setMainWidget(w);
	slotChangedSelection();
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Action slots							//
//									//
//////////////////////////////////////////////////////////////////////////

void MatchRequester::slotChangedSelection()
{
	bool something = (listBox->selectedItem()!=NULL);
	enableButtonOK(something);
	if (canRemember) saveCheck->setEnabled(something);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Returned results							//
//									//
//////////////////////////////////////////////////////////////////////////

QString MatchRequester::selectedEntry() const
{
	QListBoxItem *selected = listBox->selectedItem();
	return (selected!=NULL ? selected->text() : QString::null);
}


bool MatchRequester::rememberChoice() const
{
	return (saveCheck->isChecked());
}
