/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  PrboomGame								//
//  ----------								//
//									//
//  Specific game engine implementation for PrBoom.  There isn't very	//
//  much of this, since the GenericGame was written with PrBoom as	//
//  the prototype.							//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>
#include <klocale.h>

#include <qwidget.h>
#include <qdir.h>
#include <qfile.h>

#include "gamemanager.h"
#include "genericgame.h"

#include "prboomgame.h"
#include "prboomgame.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Engine information							//
//									//
//////////////////////////////////////////////////////////////////////////

class PrboomGameInfo
{
public:
	static const GameManager::gameInfo myinfo;

protected:
	static GenericGame *create(QWidget *parent);

private:
	static PrboomGameInfo initobj;
	PrboomGameInfo();
};


const GameManager::gameInfo PrboomGameInfo::myinfo =
{
	"prboom",					// key
	"PrBoom",					// name
	"http://prboom.sourceforge.net",		// url
	QString::null,					// notes
	"prboom",					// execname
	QString::null,					// execpaths
	QString::null,					// datapaths
	&PrboomGameInfo::create				// createfunc
};


PrboomGameInfo PrboomGameInfo::initobj;


PrboomGameInfo::PrboomGameInfo()
{
	GameManager::self()->add(&PrboomGameInfo::myinfo);
}


GenericGame *PrboomGameInfo::create(QWidget *parent)
{
	kdDebug(0) << k_funcinfo << endl;
	GenericGame *g = new PrboomGame(parent);
	return (g);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

PrboomGame::PrboomGame(QWidget *parent)
	: GenericGame(parent)
{
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Saved games and information						//
//									//
//////////////////////////////////////////////////////////////////////////

QStringList PrboomGame::findSavedGames()
{
	kdDebug(0) << k_funcinfo << endl;
	QStringList l;

	QDir d = QDir::home();
	if (!d.cd(".prboom"))
	{
		kdDebug(0) << k_funcinfo << "no saved game directory" << endl;
		return (l);
	}

	for (int i = 0; i<=7; ++i)			// this many save slots
	{
		QFile f(d.absFilePath(QString("prbmsav%1.dsg").arg(i)));
		if (!f.exists()) continue;		// look for save slot file

		if (!f.open(IO_ReadOnly))
		{
			kdDebug(0) << k_funcinfo << "cannot read " << f.name() << endl;
			continue;
		}

		QString desc = QString("%1: %2").arg(i);

		char buf[41];				// first 40 bytes of file
		Q_LONG len = f.readBlock(buf,sizeof(buf)-1);
		if (len>0)				// read successfully
		{
			buf[len] = '\0';
			l.append(desc.arg(buf));
		}
		else l.append(desc.arg(i18n("(Unreadable)")));
		f.close();
	}

	kdDebug(0) << k_funcinfo << "returning " << l.join(",") << endl;
	return (l);
}


const GameManager::gameInfo *PrboomGame::gameInfo()
{
	return (&PrboomGameInfo::myinfo);
}
