/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  Wad									//
//  ---									//
//									//
//  WAD file identification and information.				//
//									//
//  At the moment all of this is guessed, based on file name/size	//
//  and known information.  It would of course be much better to scan	//
//  the files and extract accurate information.  See d_main.c from	//
//  JDoom sources (deng-X.X.X.tar.gz/deng-X.X.X/Src/jDoom/d_main.c)	//
//  for one possible approach.						//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>

#include <qfileinfo.h>
#include <qstringlist.h>

#include "wad.h"

//////////////////////////////////////////////////////////////////////////
//									//
//  Identify a WAD file							//
//									//
//  Currently, based on file name and size.  There may be a number of	//
//  different files named DOOM.WAD, selected file sizes are:		//
//									//
//   Shareware		V1.9=4196020   V1.1=4274218			//
//   Registered		V1.9=11159840  V1.1=10396254			//
//   Ultimate		12408292					//
//   Freedoom Demo	5719684						//
//									//
//////////////////////////////////////////////////////////////////////////

Wad::Type Wad::identify(const QString &wad)
{
	QFileInfo inf(wad);
	if (!inf.exists()) return (Wad::Unknown);
	if (inf.extension().lower()!="wad") return (Wad::Unknown);

	const QString base = inf.baseName().lower();	// base name of file

	if (base=="doom" || base.left(5)=="doom1")	// guess which, based on size
	{
		if (inf.size()<(6000*1024)) return (Wad::Shareware);
		if (inf.size()<(11000*1024)) return (Wad::Doom1);
		return (Wad::Ultimate);
	}

	if (base=="doom2") return (Wad::Doom2);
	if (base=="tnt") return (Wad::Tnt);
	if (base=="plutonia") return (Wad::Plutonia);
							// named WADs, but used internally
	if (base=="prboom" || base=="edge") return (Wad::Invalid);
	return (Wad::Unknown);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  List of episodes							//
//									//
//////////////////////////////////////////////////////////////////////////

const QStringList Wad::episodeList(Wad::Type type)
{
	QStringList l;

	switch (type)
	{
case Wad::Doom1:
case Wad::Shareware:
case Wad::Ultimate:
		l += "E1M1: Knee-Deep in the Dead - Hangar";
		l += "E1M2: Nuclear Plant";
		l += "E1M3: Toxic Refinery";
		l += "E1M4: Command Control";
		l += "E1M5: Phobos Lab";
		l += "E1M6: Central Processing";
		l += "E1M7: Computer Station";
		l += "E1M8: Phobos Anomaly";
		l += "E1M9: Military Base";

		if (type!=Wad::Shareware)
		{
			l += "E2M1: The Shores of Hell - Deimos Anomaly";
			l += "E2M2: Containment Area";
			l += "E2M3: Refinery";
			l += "E2M4: Deimos Lab";
			l += "E2M5: Command Centre";
			l += "E2M6: Halls of the Damned";
			l += "E2M7: Spawning Vats";
			l += "E2M8: Tower of Babel";
			l += "E2M9: Fortress of Mystery";

			l += "E3M1: Inferno - Hell Keep";
			l += "E3M2: Slough of Despair";
			l += "E3M3: Pandemonium";
			l += "E3M4: House of Pain";
			l += "E3M5: Unholy Cathedral";
			l += "E3M6: Mount Erebus";
			l += "E3M7: Gate to Limbo";
			l += "E3M8: Dis";
			l += "E3M9: Warrens";

			if (type==Wad::Ultimate)
			{
				l += "E4M1: Thy Flesh Consumed - Hell Beneath";
				l += "E4M2: Perfect Hatred";
				l += "E4M3: Sever the Wicked";
				l += "E4M4: Unruly Evil";
				l += "E4M5: They Will Repent";
				l += "E4M6: Against Thee Wickedly";
				l += "E4M7: And Hell Followed";
				l += "E4M8: Unto the Cruel";
				l += "E4M9: Fear";
			}
		}
		break;

case Wad::Doom2:
		l += "01: Entryway";
		l += "02: Underhalls";
		l += "03: The Gantlet";
		l += "04: The Focus";
		l += "05: Waste Tunnels";
		l += "06: The Crusher";
		l += "07: Dead Simple";
		l += "08: Tricks and Traps";
		l += "09: The Pit";
		l += "10: Refuelling Base";
		l += "11: 'O' of Destruction";
		l += "12: The Factory";
		l += "13: Downtown";
		l += "14: Inmost Dens";
		l += "15: Industrial Zone";
		l += "16: Suburbs";
		l += "17: Tenements";
		l += "18: Courtyard";
		l += "19: The Citadel";
		l += "20: Gotcha!";
		l += "21: Nirvana";
		l += "22: Catacombs";
		l += "23: Barrels O'Fun";
		l += "24: The Chasm";
		l += "25: Bloodfalls";
		l += "26: Abandoned Mines";
		l += "27: Monster Condo";
		l += "28: Spirit World";
		l += "29: Living End";
		l += "30: Icon of Sin";
		l += "31: Wolfenstein";
		l += "32: Grosse";
		break;

case Wad::Plutonia:
		l += "01: Congo";
		l += "02: Well of Souls";
		l += "03: Aztec";
		l += "04: Caged";
		l += "05: Ghost Town";
		l += "06: Baron's Lair";
		l += "07: Caughtyard";
		l += "08: Realm";
		l += "09: Abbatoire";
		l += "10: Onslaught";
		l += "11: Hunted";
		l += "12: Speed";
		l += "13: The Crypt";
		l += "14: Genesis";
		l += "15: Twilight";
		l += "16: The Omen";
		l += "17: Compound";
		l += "18: Neurosphere";
		l += "19: NME";
		l += "20: Death Domain";
		l += "21: Slayer";
		l += "22: Impossible Mission";
		l += "23: Tombstone";
		l += "24: Final Frontier";
		l += "25: Temple of Darkness";
		l += "26: Bunker";
		l += "27: Anti-Christ";
		l += "28: The Sewers";
		l += "29: Odyssey of Noises";
		l += "30: Gateway of Hell";
		l += "31: Cyberden";
		l += "32: Go 2 It";
		break;

case Wad::Tnt:
		l += "01: System Control";
		l += "02: Human BBQ";
		l += "03: Power Control";
		l += "04: Wormhole";
		l += "05: Hanger";
		l += "06: Open Season";
		l += "07: Prison";
		l += "08: Metal";
		l += "09: Stronghold";
		l += "10: Redemption";
		l += "11: Storage Facility";
		l += "12: Crater";
		l += "13: Nukage Processing";
		l += "14: Steel Works";
		l += "15: Dead Zone";
		l += "16: Deepest Reaches";
		l += "17: Processing Area";
		l += "18: Mill";
		l += "19: Shipping/Respawning";
		l += "20: Central Processing";
		l += "21: Administration Centre";
		l += "22: Habitat";
		l += "23: Lunar Mining Project";
		l += "24: Quarry";
		l += "25: Baron's Den";
		l += "26: Ballistyx";
		l += "27: Mount Pain";
		l += "28: Heck";
		l += "29: River Styx";
		l += "30: Last Call";
		l += "31: Pharoah";
		l += "32: Caribbean";
		break;
	}

	return (l);
}
